@@ -118,8 +118,8 @@ usage()
            "sense (10) cdb)\n"
            "    --maxlen=LEN|-m LEN    max response length (allocation "
            "length in cdb)\n"
-           "                           (def: 0 -> 4096 or 252 (for MODE SENSE 6) "
-           "bytes)\n"
+           "                           (def: 0 -> 4096 or 252 (for MODE "
+           "SENSE 6) bytes)\n"
            "    --page=PG|-p PG    page code to fetch (def: 63)\n"
            "    --page=PG,SPG|-p PG,SPG\n"
            "                       page code and subpage code to fetch "
