@@ -1,3 +1,13 @@
+/* A utility program originally written for the Linux OS SCSI subsystem.
+ *  Copyright (C) 2004-2012 D. Gilbert
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2, or (at your option)
+ *  any later version.
+ *
+ *  This program issues the SCSI PERSISTENT IN and OUT commands.
+ */
+
 #include <unistd.h>
 #include <fcntl.h>
 #include <stdio.h>
@@ -16,18 +26,7 @@
 #include "sg_cmds_basic.h"
 #include "sg_cmds_extra.h"
 
-/* A utility program originally written for the Linux OS SCSI subsystem.
-*  Copyright (C) 2004-2009 D. Gilbert
-*  This program is free software; you can redistribute it and/or modify
-*  it under the terms of the GNU General Public License as published by
-*  the Free Software Foundation; either version 2, or (at your option)
-*  any later version.
-
-   This program issues the SCSI PERSISTENT IN and OUT commands.
-
-*/
-
-static char * version_str = "0.37 20090903";
+static char * version_str = "0.38 20120224";
 
 
 #define PRIN_RKEY_SA     0x0
@@ -198,6 +197,10 @@ usage()
             "Performs a SCSI PERSISTENT RESERVE (IN or OUT) command\n");
 }
 
+/* If num_tids==0 then only one TransportID is assumed with len bytes in
+ * it. If num_tids>0 then that many TransportIDs is assumed, each in an
+ * element that is MX_TID_LEN bytes long (and the 'len' argument is
+ * ignored). */
 static void
 decode_transport_id(const char * leadin, unsigned char * ucp, int len,
                     int num_tids)
@@ -207,7 +210,7 @@ decode_transport_id(const char * leadin, unsigned char * ucp, int len,
     int bump;
 
     if (num_tids > 0)
-        len = num_tids * MX_TID_LEN; 
+        len = num_tids * MX_TID_LEN;
     for (k = 0, bump = MX_TID_LEN; k < len; k += bump, ucp += bump) {
         if ((len < 24) || (0 != (len % 4)))
             printf("%sTransport Id short or not multiple of 4 "
@@ -222,7 +225,7 @@ decode_transport_id(const char * leadin, unsigned char * ucp, int len,
             if (0 != format_code)
                 printf("%s  [Unexpected format code: %d]\n", leadin,
                        format_code);
-            dStrHex((const char *)&ucp[8], 8, 0);
+            dStrHex((const char *)&ucp[8], 8, -1);
             break;
         case TPROTO_SPI: /* Parallel SCSI */
             printf("%s  Parallel SCSI initiator SCSI address: 0x%x\n",
@@ -236,21 +239,21 @@ decode_transport_id(const char * leadin, unsigned char * ucp, int len,
         case TPROTO_SSA:
             printf("%s  SSA (transport id not defined):\n", leadin);
             printf("%s  format code: %d\n", leadin, format_code);
-            dStrHex((const char *)ucp, ((len > 24) ? 24 : len), 0);
+            dStrHex((const char *)ucp, ((len > 24) ? 24 : len), -1);
             break;
         case TPROTO_1394: /* IEEE 1394 */
             printf("%s  IEEE 1394 EUI-64 name:\n", leadin);
             if (0 != format_code)
                 printf("%s  [Unexpected format code: %d]\n", leadin,
                        format_code);
-            dStrHex((const char *)&ucp[8], 8, 0);
+            dStrHex((const char *)&ucp[8], 8, -1);
             break;
         case TPROTO_SRP:
             printf("%s  RDMA initiator port identifier:\n", leadin);
             if (0 != format_code)
                 printf("%s  [Unexpected format code: %d]\n", leadin,
                        format_code);
-            dStrHex((const char *)&ucp[8], 16, 0);
+            dStrHex((const char *)&ucp[8], 16, -1);
             break;
         case TPROTO_ISCSI:
             printf("%s  iSCSI ", leadin);
@@ -261,7 +264,7 @@ decode_transport_id(const char * leadin, unsigned char * ucp, int len,
                 printf("name and session id: %.*s\n", num, &ucp[4]);
             else {
                 printf("  [Unexpected format code: %d]\n", format_code);
-                dStrHex((const char *)ucp, num + 4, 0);
+                dStrHex((const char *)ucp, num + 4, -1);
             }
             break;
         case TPROTO_SAS:
@@ -279,18 +282,36 @@ decode_transport_id(const char * leadin, unsigned char * ucp, int len,
         case TPROTO_ADT:
             printf("%s  ADT:\n", leadin);
             printf("%s  format code: %d\n", leadin, format_code);
-            dStrHex((const char *)ucp, ((len > 24) ? 24 : len), 0);
+            dStrHex((const char *)ucp, ((len > 24) ? 24 : len), -1);
             break;
         case TPROTO_ATA:
             printf("%s  ATAPI:\n", leadin);
             printf("%s  format code: %d\n", leadin, format_code);
-            dStrHex((const char *)ucp, ((len > 24) ? 24 : len), 0);
+            dStrHex((const char *)ucp, ((len > 24) ? 24 : len), -1);
+            break;
+        case TPROTO_UAS:
+            printf("%s  UAS:\n", leadin);
+            printf("%s  format code: %d\n", leadin, format_code);
+            dStrHex((const char *)ucp, ((len > 24) ? 24 : len), -1);
+            break;
+        case TPROTO_SOP:
+            printf("%s  SOP ", leadin);
+            num = ((ucp[2] << 8) | ucp[3]);
+            if (0 == format_code)
+                printf("Routing ID: 0x%x\n", num);
+            else {
+                printf("  [Unexpected format code: %d]\n", format_code);
+                dStrHex((const char *)ucp, ((len > 24) ? 24 : len), -1);
+            }
             break;
         case TPROTO_NONE:
+            fprintf(stderr, "%s  No specified protocol\n", leadin);
+            /* dStrHex((const char *)ucp, ((len > 24) ? 24 : len), -1); */
+            break;
         default:
             fprintf(stderr, "%s  unknown protocol id=0x%x  "
                     "format_code=%d\n", leadin, proto_id, format_code);
-            dStrHex((const char *)ucp, ((len > 24) ? 24 : len), 0);
+            dStrHex((const char *)ucp, ((len > 24) ? 24 : len), -1);
             break;
         }
     }
@@ -645,7 +666,7 @@ decode_sym_transportid(const char * lcp, unsigned char * tidp)
                 tidp[4 + j] = b | n;
                 ++j;
             } else
-                b = n << 4; 
+                b = n << 4;
         }
         return 1;
     } else if ((0 == memcmp("spi,", lcp, 4)) ||
@@ -685,7 +706,7 @@ decode_sym_transportid(const char * lcp, unsigned char * tidp)
                 tidp[8 + j] = b | n;
                 ++j;
             } else
-                b = n << 4; 
+                b = n << 4;
         }
         return 1;
     } else if ((0 == memcmp("sbp,", lcp, 4)) ||
@@ -711,7 +732,7 @@ decode_sym_transportid(const char * lcp, unsigned char * tidp)
                 tidp[8 + j] = b | n;
                 ++j;
             } else
-                b = n << 4; 
+                b = n << 4;
         }
         return 1;
     } else if ((0 == memcmp("srp,", lcp, 4)) ||
@@ -737,7 +758,7 @@ decode_sym_transportid(const char * lcp, unsigned char * tidp)
                 tidp[8 + j] = b | n;
                 ++j;
             } else
-                b = n << 4; 
+                b = n << 4;
         }
         return 1;
     } else if (0 == memcmp("iqn.", lcp, 4)) {
@@ -754,7 +775,7 @@ decode_sym_transportid(const char * lcp, unsigned char * tidp)
         else if (0 != (alen % 4))
             alen = ((alen / 4) + 1) * 4;
         if (alen > 241) { /* sam5r02.pdf A.2 (Annex) */
-            fprintf(stderr, "iSCSI name too long, alen=%d\n", alen); 
+            fprintf(stderr, "iSCSI name too long, alen=%d\n", alen);
             return 0;
         }
         tidp[3] = alen & 0xff;
